==> jc-1.4.0.tar.gz: java/awt/GridBagConstraints.h <==
// public class java.awt.GridBagConstraints

// class file dependencies
// @dep_class 630b9cc895c421a0 java_awt_GridBagConstraints
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_GridBagConstraints_H_
#define _JC_java_awt_GridBagConstraints_H_

// Forward structure declarations
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_awt_GridBagConstraints$sub_refs	_jc_java_awt_GridBagConstraints$sub_refs;
typedef struct _jc_java_awt_GridBagConstraints$sub_nonrefs	_jc_java_awt_GridBagConstraints$sub_nonrefs;
typedef struct _jc_java_awt_GridBagConstraints$refs	_jc_java_awt_GridBagConstraints$refs;
typedef struct _jc_java_awt_GridBagConstraints$nonrefs	_jc_java_awt_GridBagConstraints$nonrefs;
typedef struct _jc_java_awt_GridBagConstraints$object	_jc_java_awt_GridBagConstraints$object;

typedef struct _jc_java_awt_GridBagConstraints$fields_struct	_jc_java_awt_GridBagConstraints$fields_struct;
typedef const struct _jc_java_awt_GridBagConstraints$vmethods	_jc_java_awt_GridBagConstraints$vmethods;
typedef const struct _jc_java_awt_GridBagConstraints$vtable	_jc_java_awt_GridBagConstraints$vtable;
typedef const struct _jc_java_awt_GridBagConstraints$vtype	_jc_java_awt_GridBagConstraints$vtype;

// Class fields structure
struct _jc_java_awt_GridBagConstraints$fields_struct {
	jlong	serialVersionUID;
	jint	BOTH;
	jint	CENTER;
	jint	EAST;
	jint	FIRST__5fLINE__5fEND;
	jint	FIRST__5fLINE__5fSTART;
	jint	HORIZONTAL;
	jint	LAST__5fLINE__5fEND;
	jint	LAST__5fLINE__5fSTART;
	jint	LINE__5fEND;
	jint	LINE__5fSTART;
	jint	NONE;
	jint	NORTH;
	jint	NORTHEAST;
	jint	NORTHWEST;
	jint	PAGE__5fEND;
	jint	PAGE__5fSTART;
	jint	RELATIVE;
	jint	REMAINDER;
	jint	SOUTH;
	jint	SOUTHEAST;
	jint	SOUTHWEST;
	jint	VERTICAL;
	jint	WEST;
};
extern _jc_java_awt_GridBagConstraints$fields_struct _jc_java_awt_GridBagConstraints$class_fields;

// Constructors
extern void _jc_java_awt_GridBagConstraints$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_GridBagConstraints$object *);
extern void _jc_java_awt_GridBagConstraints$method$_init$eb5363d1ab34ea3e(_jc_env *, struct _jc_java_awt_GridBagConstraints$object *, jint, jint, jint, jint, jdouble, jdouble, jint, jint, struct _jc_java_awt_Insets$object *, jint, jint);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_GridBagConstraints$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_awt_GridBagConstraints$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_GridBagConstraints$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_java_awt_GridBagConstraints$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_awt_GridBagConstraints$object *);
};

// Vtable
struct _jc_java_awt_GridBagConstraints$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_GridBagConstraints$vmethods	java_awt_GridBagConstraints;
};

// Vtype
struct _jc_java_awt_GridBagConstraints$vtype {
	_jc_type			type;
	_jc_java_awt_GridBagConstraints$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_GridBagConstraints$sub_refs {
	struct _jc_java_awt_Insets$object	*insets;
};

// Reference instance fields (object)
struct _jc_java_awt_GridBagConstraints$refs {
    _jc_java_awt_GridBagConstraints$sub_refs	java_awt_GridBagConstraints;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_GridBagConstraints$sub_nonrefs {
	jint	anchor;
	jint	fill;
	jint	gridheight;
	jint	gridwidth;
	jint	gridx;
	jint	gridy;
	jint	ipadx;
	jint	ipady;
	jdouble	weightx;
	jdouble	weighty;
};

// Non-reference instance fields (object)
struct _jc_java_awt_GridBagConstraints$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_GridBagConstraints$sub_nonrefs	java_awt_GridBagConstraints;
};

// Object instance structure
struct _jc_java_awt_GridBagConstraints$object {
	_jc_java_awt_GridBagConstraints$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_GridBagConstraints$vtype	*vtype;
	_jc_java_awt_GridBagConstraints$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_GridBagConstraints$vtype _jc_java_awt_GridBagConstraints$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_GridBagConstraints, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_GridBagConstraints$class_object;

#endif	/* _JC_java_awt_GridBagConstraints_H_ */

==> jc-1.4.6.tar.gz: java/awt/GridBagConstraints.h <==
// public class java.awt.GridBagConstraints

// class file dependencies
// @dep_class 630b9cc895c421a0 java_awt_GridBagConstraints
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_GridBagConstraints_H_
#define _JC_java_awt_GridBagConstraints_H_

// Forward structure declarations
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_awt_GridBagConstraints$sub_refs	_jc_java_awt_GridBagConstraints$sub_refs;
typedef struct _jc_java_awt_GridBagConstraints$sub_nonrefs	_jc_java_awt_GridBagConstraints$sub_nonrefs;
typedef struct _jc_java_awt_GridBagConstraints$refs	_jc_java_awt_GridBagConstraints$refs;
typedef struct _jc_java_awt_GridBagConstraints$nonrefs	_jc_java_awt_GridBagConstraints$nonrefs;
typedef struct _jc_java_awt_GridBagConstraints$object	_jc_java_awt_GridBagConstraints$object;

typedef struct _jc_java_awt_GridBagConstraints$fields_struct	_jc_java_awt_GridBagConstraints$fields_struct;
typedef const struct _jc_java_awt_GridBagConstraints$vmethods	_jc_java_awt_GridBagConstraints$vmethods;
typedef const struct _jc_java_awt_GridBagConstraints$vtable	_jc_java_awt_GridBagConstraints$vtable;
typedef const struct _jc_java_awt_GridBagConstraints$vtype	_jc_java_awt_GridBagConstraints$vtype;

// Class fields structure
struct _jc_java_awt_GridBagConstraints$fields_struct {
	jlong	serialVersionUID;
	jint	BOTH;
	jint	CENTER;
	jint	EAST;
	jint	FIRST__5fLINE__5fEND;
	jint	FIRST__5fLINE__5fSTART;
	jint	HORIZONTAL;
	jint	LAST__5fLINE__5fEND;
	jint	LAST__5fLINE__5fSTART;
	jint	LINE__5fEND;
	jint	LINE__5fSTART;
	jint	NONE;
	jint	NORTH;
	jint	NORTHEAST;
	jint	NORTHWEST;
	jint	PAGE__5fEND;
	jint	PAGE__5fSTART;
	jint	RELATIVE;
	jint	REMAINDER;
	jint	SOUTH;
	jint	SOUTHEAST;
	jint	SOUTHWEST;
	jint	VERTICAL;
	jint	WEST;
};
extern _jc_java_awt_GridBagConstraints$fields_struct _jc_java_awt_GridBagConstraints$class_fields;

// Constructors
extern void _jc_java_awt_GridBagConstraints$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_GridBagConstraints$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_GridBagConstraints$method$_init$eb5363d1ab34ea3e(_jc_env *, struct _jc_java_awt_GridBagConstraints$object *, jint, jint, jint, jint, jdouble, jdouble, jint, jint, struct _jc_java_awt_Insets$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_GridBagConstraints$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_awt_GridBagConstraints$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_GridBagConstraints$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_java_awt_GridBagConstraints$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_awt_GridBagConstraints$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_GridBagConstraints$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_GridBagConstraints$vmethods	java_awt_GridBagConstraints;
};

// Vtype
struct _jc_java_awt_GridBagConstraints$vtype {
	_jc_type			type;
	_jc_java_awt_GridBagConstraints$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_GridBagConstraints$sub_refs {
	struct _jc_java_awt_Insets$object	*insets;
};

// Reference instance fields (object)
struct _jc_java_awt_GridBagConstraints$refs {
    _jc_java_awt_GridBagConstraints$sub_refs	java_awt_GridBagConstraints;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_GridBagConstraints$sub_nonrefs {
	jint	anchor;
	jint	fill;
	jint	gridheight;
	jint	gridwidth;
	jint	gridx;
	jint	gridy;
	jint	ipadx;
	jint	ipady;
	jdouble	weightx;
	jdouble	weighty;
};

// Non-reference instance fields (object)
struct _jc_java_awt_GridBagConstraints$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_GridBagConstraints$sub_nonrefs	java_awt_GridBagConstraints;
};

// Object instance structure
struct _jc_java_awt_GridBagConstraints$object {
	_jc_java_awt_GridBagConstraints$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_GridBagConstraints$vtype	*vtype;
	_jc_java_awt_GridBagConstraints$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_GridBagConstraints$vtype _jc_java_awt_GridBagConstraints$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_GridBagConstraints, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_GridBagConstraints$class_object;

#endif	/* _JC_java_awt_GridBagConstraints_H_ */
